﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Controls;
using Infragistics.Controls.Timelines;

namespace AdjustXamTimeLineTooltip
{
    public partial class MainPage : UserControl
    {
        private XamZoombar Zoombar { get; set; }
        private bool LayoutUpdated { get; set; }

        List<DateTime> timePeriod = new List<DateTime>();

        public MainPage()
        {
            InitializeComponent();
            LoadData();
        }

        private void LoadData()
        {
            DateTime startdate = new DateTime(2012, 1, 7);
            for (int i = 0; i < 52; i++)
            {
                timePeriod.Add(startdate.AddDays(i * 7));
            }

            #region "XamTimeLine Control"

            Style xamZoomStyle = new Style(typeof(XamZoombar));
            xamZoomStyle.Setters.Add(new Setter(NameProperty, "Zoombar"));

            XamTimeline xamTimeline = new XamTimeline();
            xamTimeline.ZoombarStyle = xamZoomStyle;
            xamTimeline.Width = 587;
            xamTimeline.LayoutUpdated += new EventHandler(xamTimeline_LayoutUpdated);
            xamTimeline.VerticalAlignment = System.Windows.VerticalAlignment.Bottom;
            xamTimeline.Style = this.Resources["XamTimelineStyleDefault"] as Style;
            xamTimeline.Name = "xamTimeline";
            this.xamTimelinePanel.Children.Add(xamTimeline);
            DateTimeSeries dateTimeSeries = new DateTimeSeries();

            foreach (var s in timePeriod)
            {
                DateTimeEntry dateEntry = new DateTimeEntry();
                dateEntry.Time = (DateTime)s;
                dateTimeSeries.Entries.Add(dateEntry);
            }

            xamTimeline.Series.Add(dateTimeSeries);

            DateTimeAxis axis = new DateTimeAxis()
            {
                Minimum = (DateTime)timePeriod.Min(),
                Maximum = (DateTime)timePeriod.Max(),
                AutoRange = false,
                UnitType = DateTimeUnitType.Weeks,
                Unit = 2
            };
            xamTimeline.Axis = axis;

            #endregion

            #region "Apply Button"

            Button reassignTimeline = new Button();
            reassignTimeline.Name = "TimeLineAplly";
            reassignTimeline.Height = 20;
            reassignTimeline.Width = 52;
            reassignTimeline.HorizontalAlignment = System.Windows.HorizontalAlignment.Center;
            reassignTimeline.VerticalAlignment = System.Windows.VerticalAlignment.Bottom;
            reassignTimeline.Content = "Apply";
            reassignTimeline.Click += new RoutedEventHandler(reassignTimeline_Click);
            reassignTimeline.Margin = new Thickness(10, 0, 0, 0);
            xamTimelinePanel.Children.Add(reassignTimeline);

            #endregion

        }

        void reassignTimeline_Click(object sender, RoutedEventArgs e)
        {
            DateTimeAxis dateTimeAxis = ((XamTimeline)(this.FindName("xamTimeline"))).Axis as DateTimeAxis;
            DateTime leftVisible = dateTimeAxis.VisibleMinimum;
            DateTime rightVisible = dateTimeAxis.VisibleMaximum;

            DateTime left = dateTimeAxis.ActualMinimum;
            DateTime right = dateTimeAxis.ActualMaximum;

            string str = "Selected StartData = " + leftVisible.ToShortDateString() + "  Selected EndDate = " + rightVisible.ToShortDateString() + "\n\n";
            str += "Actual StartData = " + left.ToShortDateString() + "  Actual EndDate = " + right.ToShortDateString() + "\n\nScroll Position:" + dateTimeAxis.ScrollPosition + "      Scroll Scale:" + dateTimeAxis.ScrollScale + "\nCurrent Scroll Position:" + dateTimeAxis.ScrollPosition;

            TheTextBox.Text = str;
        }

        void xamTimeline_LayoutUpdated(object sender, EventArgs e)
        {
            if (this.LayoutUpdated)
            {
                return;
            }
            this.LayoutUpdated = true;
            this.Zoombar = this.FindName("Zoombar") as XamZoombar;
            this.Zoombar.ZoomChanged += new EventHandler<ZoomChangedEventArgs>(Zoombar_ZoomChanged);
            InitToolTips();
        }

        void Zoombar_ZoomChanged(object sender, ZoomChangedEventArgs e)
        {
            InitToolTips();
        }

        private void InitToolTips()
        {
            DateTimeAxis axis = ((XamTimeline)(this.FindName("xamTimeline"))).Axis as DateTimeAxis;
            if (axis != null)
            {
                List<DateTime> selectedRangeOfDate = timePeriod.Where(a => a.Date >= axis.VisibleMinimum.Date && a.Date <= axis.VisibleMaximum.Date).Select(a => a.Date).Distinct().OrderBy(a => a).Cast<DateTime>().ToList();
                if (selectedRangeOfDate != null && selectedRangeOfDate.Any())
                {
                    DateTime NearAboutStartDate = selectedRangeOfDate.First();
                    DateTime NearAboutEndDate = selectedRangeOfDate.Last();
                    TimeSpan tEndate = (DateTime)(timePeriod.Where(a => a.Date <= axis.VisibleMaximum).OrderByDescending(a => a.Date).FirstOrDefault().Date) - axis.VisibleMaximum;
                    double ScaletomoveEnd = tEndate.Days * (1.0 / (timePeriod.Select(a => a.Date).Distinct().Count() * 7));
                    double currentscale = axis.ScrollScale;
                    double movedscale = currentscale + ScaletomoveEnd;
                    axis.ScrollScale = movedscale;

                    string tooltip = string.Format("{0} - {1} ,\t Selected weeks: {2}"
                                , NearAboutStartDate.ToShortDateString()
                                , NearAboutEndDate.ToShortDateString()
                                , selectedRangeOfDate.Count);

                    Style thumbStyle = new Style(typeof(ContentControl));
                    thumbStyle.BasedOn = this.Zoombar.HorizontalThumbStyle;
                    thumbStyle.Setters.Add(new Setter(ToolTipService.ToolTipProperty, tooltip));
                    this.Zoombar.HorizontalThumbStyle = thumbStyle;
                }
            }
        }
    }
}
